@@ -297,12 +297,17 @@ H5T__conv_enum(const H5T_t *src, const H5T_t *dst, H5T_cdata_t *cdata, const H5T
                 for (i = 0; i < nelmts; i++, s += src_delta, d += dst_delta) {
                     
                     
-                    if (1 == src_sh->size)
+                    if (1 == src_sh->size) {
                         n = *((signed char *)s);
-                    else if (sizeof(short) == src_sh->size)
-                        n = *((short *)((void *)s));
-                    else
-                        n = *((int *)((void *)s));
+                    }
+                    else if (sizeof(short) == src_sh->size) {
+                        short tmp;
+                        H5MM_memcpy(&tmp, s, sizeof(short));
+                        n = tmp;
+                    }
+                    else {
+                        H5MM_memcpy(&n, s, sizeof(int));
+                    }
                     n -= priv->base;
                     if (n < 0 || (unsigned)n >= priv->length || priv->src2dst[n] < 0) {
                         
